@@ -23,17 +23,6 @@ from gvtest import (  # pylint: disable=wrong-import-position
 )
 
 
-def is_win64() -> bool:
-    """
-    is the Graphviz under test targeting the x64 Windows API?
-    """
-    if platform.system() != "Windows":
-        return False
-    if os.getenv("project_platform") != "x64":
-        return False
-    return True
-
-
 @pytest.mark.parametrize(
     "binary",
     [
@@ -114,14 +103,10 @@ def test_existence(binary: str):
             check_that_tool_does_not_exist(binary, os_id)
             pytest.skip(f"{binary} is not built with MSBuild (#1837)")
 
-    if binary == "mingle" and is_cmake() and (is_win64() or is_mingw()):
+    if binary == "mingle" and is_cmake() and is_mingw():
         check_that_tool_does_not_exist(binary, os_id)
         pytest.skip(f"{binary} is not built on some Windows due to lacking libANN")
 
-    if binary == "diffimg" and is_win64():
-        check_that_tool_does_not_exist(binary, os_id)
-        pytest.skip(f"{binary} is not built on 64-bit Windows due to lacking libgd")
-
     if binary == "gvedit" and platform.system() == "Windows" and not is_mingw():
         check_that_tool_does_not_exist(binary, os_id)
         pytest.skip(f"{binary} is not built on Windows due to lacking Qt")
@@ -163,11 +148,6 @@ def check_that_tool_does_not_exist(tool, os_id):
     )
 
 
-@pytest.mark.xfail(
-    is_cmake() and not is_mingw() and is_win64(),
-    reason="png:gd unavailable when built with CMake",
-    strict=True,
-)  # FIXME
 def test_1786():
     """
     png:gd format should be supported
