@@ -29,13 +29,13 @@
 
 #include <stdlib.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/cgraph.h>
-#include <cgraph/exit.h>
 #include <cgraph/gv_math.h>
 #include <cgraph/ingraphs.h>
 #include <cgraph/list.h>
-#include <cgraph/unreachable.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/unreachable.h>
 
 typedef struct {
     Agrec_t h;
