@@ -14,8 +14,7 @@
  *************************************************************************/
 
 #include "config.h"
-#include <cgraph/alloc.h>
-#include <cgraph/unreachable.h>
+#include <util/alloc.h>
 
 #define STANDALONE
 #include <cgraph/cgraph.h>
@@ -28,6 +27,7 @@
 #include "mmio.h"
 #include <cgraph/agxbuf.h>
 #include <sparse/SparseMatrix.h>
+#include <util/unreachable.h>
 #include "matrix_market.h"
 #include <getopt.h>
 
@@ -98,7 +98,7 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
 	}
     }
 
-    if (SparseMatrix_known_undirected(A)) {
+    if (A->is_undirected) {
 	g = agopen("G", Agundirected, NULL);
     } else {
 	g = agopen("G", Agdirected, NULL);
