@@ -1,21 +1,23 @@
+/// @file
+/// @ingroup common_render
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/unreachable.h>
 #include <common/render.h>
 #include <label/xlabels.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/prisize_t.h>
+#include <util/unreachable.h>
 
 static int Rankdir;
 static bool Flip;
@@ -95,7 +97,7 @@ static void map_edge(edge_t * e)
 
     if (ED_spl(e) == NULL) {
 	if (!Concentrate && ED_edge_type(e) != IGNORED)
-	    agerr(AGERR, "lost %s %s edge\n", agnameof(agtail(e)),
+	    agerrorf("lost %s %s edge\n", agnameof(agtail(e)),
 		  agnameof(aghead(e)));
 	return;
     }
@@ -498,7 +500,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with label %s\n",
+		    agwarningf("no position for edge with label %s\n",
 			    ED_label(ep)->text);
 		    continue;
 		}
@@ -513,7 +515,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with tail label %s\n",
+		    agwarningf("no position for edge with tail label %s\n",
 			    ED_tail_label(ep)->text);
 		    continue;
 		}
@@ -528,7 +530,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with head label %s\n",
+		    agwarningf("no position for edge with head label %s\n",
 			    ED_head_label(ep)->text);
 		    continue;
 		}
@@ -543,7 +545,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with xlabel %s\n",
+		    agwarningf("no position for edge with xlabel %s\n",
 			    ED_xlabel(ep)->text);
 		    continue;
 		}
@@ -583,7 +585,7 @@ static void addXLabels(Agraph_t * gp)
 	fprintf(stderr, "%" PRISIZE_T " out of %" PRISIZE_T " labels positioned.\n",
 	        cnt, n_lbls);
     else if (cnt != n_lbls)
-	agerr(AGWARN, "%" PRISIZE_T " out of %" PRISIZE_T " exterior labels positioned.\n",
+	agwarningf("%" PRISIZE_T " out of %" PRISIZE_T " exterior labels positioned.\n",
 	      cnt, n_lbls);
     free(objs);
     free(lbls);
