@@ -8,11 +8,11 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
-#include <cgraph/unused.h>
 #include <dotgen/dot.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/unused.h>
 
 /*
  * operations on the fast internal graph.
