@@ -51,10 +51,11 @@ glCompButton *glCompButtonNew(void *par, float x, float y, float w, float h,
     p->base.common.functions.mouseup = glCompButtonMouseUp;
 
     /*caption */
+    glDeleteFont(&p->base.common.font);
     p->base.common.font = glNewFontFromParent(&p->base, NULL);
     p->label = glCompLabelNew(p, caption);
-    p->label->base.common.font->justify.VJustify = glFontVJustifyCenter;
-    p->label->base.common.font->justify.HJustify = glFontHJustifyCenter;
+    p->label->base.common.font.justify.VJustify = glFontVJustifyCenter;
+    p->label->base.common.font.justify.HJustify = glFontHJustifyCenter;
     p->label->base.common.align = glAlignParent;
     /*image */
     p->image = NULL;
