@@ -20,7 +20,7 @@ static void glCompLabelDraw(void *label) {
   glCompCalcWidget(p->base.common.parent, &p->base.common, &ref);
   /*draw background */
   if (!p->transparent) {
-    glCompSetColor(&p->base.common.color);
+    glCompSetColor(p->base.common.color);
     glBegin(GL_QUADS);
     glVertex3d(ref.refPos.x, ref.refPos.y, ref.refPos.z);
     glVertex3d(ref.refPos.x + ref.width, ref.refPos.y, ref.refPos.z);
