@@ -8,23 +8,22 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
 #include <glcomp/glcomppanel.h>
 #include <glcomp/glcompfont.h>
 #include <glcomp/glcompset.h>
 #include <glcomp/glcomptexture.h>
 #include <glcomp/glutils.h>
 #include <stdbool.h>
+#include <util/alloc.h>
 
 static void glCompPanelDraw(void *o) {
   glCompPanel *p = o;
-  glCompCommon ref;
   glCompRect r;
-  ref = p->common;
-  glCompCalcWidget((glCompCommon *)p->common.parent, &p->common, &ref);
-  p->objType = glPanelObj;
+  glCompCommon ref = p->base.common;
+  glCompCalcWidget(p->base.common.parent, &p->base.common, &ref);
+  p->base.objType = glPanelObj;
 
-  if (!p->common.visible)
+  if (!p->base.common.visible)
     return;
   /*draw shadow */
   glColor4f(p->shadowcolor.R, p->shadowcolor.G, p->shadowcolor.B,
@@ -42,33 +41,32 @@ static void glCompPanelDraw(void *o) {
   r.pos.z = -0.001f;
   glCompDrawRectangle(&r);
   /*draw panel */
-  glCompDrawRectPrism(&ref.pos, ref.width, ref.height, p->common.borderWidth,
-                      0.01f, &ref.color, true);
+  glCompDrawRectPrism(&ref.pos, ref.width, ref.height,
+                      p->base.common.borderWidth, 0.01f, &ref.color, true);
   /*draw image if there is */
   if (p->image) {
-    p->image->common.callbacks.draw(p->image);
+    p->image->base.common.callbacks.draw(p->image);
   }
 }
 
 glCompPanel *glCompPanelNew(void *parentObj, float x, float y, float w,
                             float h) {
     glCompPanel *p = gv_alloc(sizeof(glCompPanel));
-    glCompInitCommon((glCompObj *) p, parentObj, x, y);
+    glCompInitCommon(&p->base, parentObj, x, y);
 
     p->shadowcolor.R = GLCOMPSET_PANEL_SHADOW_COLOR_R;
     p->shadowcolor.G = GLCOMPSET_PANEL_SHADOW_COLOR_G;
     p->shadowcolor.B = GLCOMPSET_PANEL_SHADOW_COLOR_B;
     p->shadowcolor.A = GLCOMPSET_PANEL_SHADOW_COLOR_A;
     p->shadowwidth = GLCOMPSET_PANEL_SHADOW_WIDTH;
-    p->common.borderWidth = GLCOMPSET_PANEL_BORDERWIDTH;
+    p->base.common.borderWidth = GLCOMPSET_PANEL_BORDERWIDTH;
 
+    p->base.common.width = w;
+    p->base.common.height = h;
 
-    p->common.width = w;
-    p->common.height = h;
-
-    p->common.font = glNewFontFromParent((glCompObj *) p, NULL);
+    p->base.common.font = glNewFontFromParent(&p->base, NULL);
     p->text = NULL;
-    p->common.functions.draw = glCompPanelDraw;
+    p->base.common.functions.draw = glCompPanelDraw;
     p->image = NULL;
     return p;
 }
