@@ -15,19 +15,20 @@
 #include <ast/ast.h>
 #include <ast/error.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
-#include <cgraph/strcasecmp.h>
-#include <cgraph/unreachable.h>
-#include <cgraph/unused.h>
 #include <gvpr/actions.h>
 #include <gvpr/compile.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <util/alloc.h>
+#include <util/strcasecmp.h>
+#include <util/unreachable.h>
+#include <util/unused.h>
 
 #define KINDS(p)                                                               \
   ((AGTYPE(p) == AGRAPH) ? "graph" : (AGTYPE(p) == AGNODE) ? "node" : "edge")
@@ -100,15 +101,15 @@ long rindexOf(char *s1, char *s2) {
 }
 
 /* match:
- * Return index of pattern pat in string str, or -1
+ * Return index of pattern pat in string str, or SIZE_MAX
  */
-int match(char *str, char *pat) {
-  int sub[2];
+size_t match(char *str, char *pat) {
+  size_t sub[2];
 
   if (strgrpmatch(str, pat, sub, 1, 0)) {
     return (sub[0]);
   } else
-    return -1;
+    return SIZE_MAX;
 }
 
 /* copyAttr:
@@ -259,10 +260,9 @@ static Agraph_t *cloneSubg(Agraph_t *tgt, Agraph_t *g, Dt_t *emap) {
   return ng;
 }
 
-static int cmppair(Dt_t *d, Agedge_t **key1, Agedge_t **key2, Dtdisc_t *disc) {
-  (void)d;
-  (void)disc;
-
+static int cmppair(void *k1, void *k2) {
+  const Agedge_t **key1 = k1;
+  const Agedge_t **key2 = k2;
   if (*key1 > *key2)
     return 1;
   else if (*key1 < *key2)
@@ -275,7 +275,7 @@ static Dtdisc_t edgepair = {
     .key = offsetof(edgepair_t, key),
     .size = sizeof(Agedge_t *),
     .link = offsetof(edgepair_t, link),
-    .comparf = (Dtcompar_f)cmppair,
+    .comparf = cmppair,
 };
 
 /* cloneGraph:
@@ -288,7 +288,7 @@ static void cloneGraph(Agraph_t *tgt, Agraph_t *src) {
   Agraph_t *sg;
   char *name;
   Dt_t *emap = dtopen(&edgepair, Dtoset);
-  edgepair_t *data = malloc(sizeof(edgepair_t) * agnedges(src));
+  edgepair_t *data = gv_calloc(agnedges(src), sizeof(edgepair_t));
   edgepair_t *ep = data;
 
   for (t = agfstnode(src); t; t = agnxtnode(src, t)) {
@@ -785,9 +785,9 @@ char *canon(Expr_t *pgm, char *arg) {
 #include "../common/colxlate.c"
 
 /* colorx:
- * RGB, RGBA, HSV, HSVA, CMYK
+ * RGB, RGBA, HSV, HSVA
  */
-char *colorx(Expr_t *ex, char *incolor, char *fmt) {
+char *colorx(Expr_t *ex, const char *incolor, char *fmt) {
   gvcolor_t color = {{{0}}, 0};
   color_type_t type;
   int rc;
@@ -807,9 +807,6 @@ char *colorx(Expr_t *ex, char *incolor, char *fmt) {
       alpha = 1;
     else
       alpha = 0;
-  } else if (*fmt == 'C') {
-    type = CMYK_BYTE;
-    alpha = 0;
   } else
     return "";
 
@@ -832,10 +829,6 @@ char *colorx(Expr_t *ex, char *incolor, char *fmt) {
     if (alpha)
       agxbprint(&fp, "%02x", color.u.rgba[3]);
     break;
-  case CMYK_BYTE:
-    agxbprint(&fp, "#%02x%02x%02x%02x", color.u.cmyk[0], color.u.cmyk[1],
-              color.u.cmyk[2], color.u.cmyk[3]);
-    break;
   default:
     break;
   }
