@@ -14,11 +14,9 @@
  */
 
 #include <assert.h>
-#include <cgraph/alloc.h>
 #include <cgraph/gv_ctype.h>
 #include <neatogen/neato.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/startswith.h>
 #include <common/utils.h>
 #include <float.h>
 #include <math.h>
@@ -36,8 +34,10 @@
 #include <vpsc/csolve_VPSC.h>
 #include <neatogen/quad_prog_vpsc.h>
 #endif
-#include <cgraph/strcasecmp.h>
 #include <stddef.h>
+#include <util/alloc.h>
+#include <util/startswith.h>
+#include <util/strcasecmp.h>
 
 #define SEPFACT         0.8 // default esep/sep
 
