@@ -22,11 +22,11 @@
 #include <gvc/gvplugin_device.h>
 #include <gvc/gvio.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <common/color.h>
+#include <util/prisize_t.h>
 #include <util/streq.h>
+#include <util/unreachable.h>
 
 /* Number of points to split splines into */
 #define BEZIERSUBDIVISION 6
